magneticalc.Perspective_Presets.Perspective_Presets

# ``magneticalc`.`Perspective_Presets`.`Perspective_Presets``

class documentation

`class Perspective_Presets:`

View In Hierarchy

Perspective_Presets class.

Static Method | `get_by_id` | Selects a preset by name.
Class Variable | `Isometric` | Undocumented
Class Variable | `List` | Undocumented
Class Variable | `PlaneXY` | Undocumented
Class Variable | `PlaneXZ` | Undocumented
Class Variable | `PlaneYZ` | Undocumented

@staticmethod
def get_by_id(_id_: `str`) -> `dict`:

Selects a preset by name.

Parameters
_id_: `str` | Preset ID

Returns
`dict` | Preset parameters

Isometric =

Undocumented

List =

Undocumented

PlaneXY: `dict` =

Undocumented

PlaneXZ: `dict` =

Undocumented

PlaneYZ: `dict` =

Undocumented